% Definicion funciones A(y), T(y), R(y)
switch(canal.tipo)
  case 1 %RECTANGULAR

    function A=crossArea(y,canal) %area(y)
      %A=crossArea(y,canal) also as canal.area(y)
      A=canal.param(1)*y;
    endfunction

    function T=surfaceWidth(y,canal)  %anchosl(y)
    %T = surfaceWidth(y,canal) also as canal.anchosl(y)
      T=canal.param(1);
    endfunction

    % Shortway to use within the structure of a particular channel
    canal.area = @(y) crossArea(y,canal);
    canal.anchosl = @(y) surfaceWidth(y,canal);

    function R=hydraulicRadius(y,canal) %Rh(y)
      % R=hydraulicRadius(y,canal) also as canal.Rh(y)
      R=  canal.param(1)*y./(canal.param(1)+2*y);
    endfunction
    
    canal.Rh = @(y) hydraulicRadius(y,canal);

  case 2 % TRAPEZOIDAL
    function A=crossArea(y,canal)
      %A=crossArea(y,canal) also as canal.area(y)
      A=(canal.param(1)+canal.param(2)*y).*y;
    endfunction

    function T=surfaceWidth(y,canal)
    %T = surfaceWidth(y,canal) also as canal.anchosl(y)
      T=canal.param(1)+2*canal.param(2)*y;
    endfunction

    canal.area = @(y) crossArea(y,canal);
    canal.anchosl = @(y) surfaceWidth(y,canal);

    function R=hydraulicRadius(y,canal)
      % R=hydraulicRadius(y,canal) also as canal.Rh(y)
      R=(canal.param(1)+canal.param(2)*y).*y ./ (canal.param(1)+2*sqrt(1+canal.param(2)^2)*y);
    endfunction

    canal.Rh = @(y) hydraulicRadius(y,canal);

  case 6 %CIRCULAR
    function A=crossArea(y,canal)
     %A=crossArea(y,canal) also as canal.area(y)
      R=  canal.param(1)*y./(canal.param(1)+2*y);
      tita= acos(1-2*y/canal.param(1));
      A=0.25*(tita-0.5*sin(2*tita))*canal.param(1)^2;
    endfunction
    function T=surfaceWidth(y,canal)
    %T = surfaceWidth(y,canal) also as canal.anchosl(y)
      T=2*sqrt(y.*(canal.param(1)-y));
    endfunction
    function R=hydraulicRadius(y,canal)
      % R=hydraulicRadius(y,canal) also as canal.Rh(y)
      tita= acos(1-2*y/canal.param(1));
      R= area(y)./ (tita*canal.param(1));
    endfunction

  case 20 %plantilla
    function A=crossArea(y)
      global canal;

    endfunction
    function T=surfaceWidth(y)
      global canal;

    endfunction
    function R=hydraulicRadius(y)
      global canal;
      
    endfunction
    canal.area = @(y) crossArea(y,canal);
    canal.anchosl = @(y) surfaceWidth(y,canal);
    canal.Rh = @(y) hydraulicRadius(y,canal);


  
endswitch


%% Fr y Ie

function Frcuadrado = Fr2(y,Q,canal) %Fr2(y,Q)
  g=9.81;
  Frcuadrado = canal.alfa*Q.^2.*canal.anchosl(y)./(g*canal.area(y).^3*canal.costitas);
endfunction

function valueIe = Ie(y,Q,canal)
%  global canal;
  valueIe = canal.n^2*Q.^2 ./(canal.area(y).^2.*canal.Rh(y).^(4/3));
endfunction
